@@ -145,7 +145,7 @@ Qt::DropActions StatisticsModel::supportedDragActions() const
 KEduVocContainer *StatisticsModel::rootContainer() const
 {
     if (!m_doc) {
-        return 0;
+        return nullptr;
     }
     return m_doc->lesson();
 }
@@ -181,3 +181,5 @@ std::shared_ptr<KEduVocDocument> StatisticsModel::document() const
 {
     return m_doc;
 }
+
+#include "moc_statisticsmodel.cpp"
